"use strict";
/**
 * @license
 * Copyright 2018 Peter Safranek
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const TSLint = require("tslint");
/**
 * This rule makes sure that import statements always import a symbol.
 */
class Rule extends TSLint.Rules.AbstractRule {
    apply(sourceFile) {
        return this.applyWithWalker(new NoEmptyImportsWalker(sourceFile, this.getOptions()));
    }
}
Rule.FAILURE_MESSAGE = 'Empty import statements not allowed.';
exports.Rule = Rule;
class NoEmptyImportsWalker extends TSLint.RuleWalker {
    visitImportDeclaration(node) {
        const namedBindings = node.importClause && node.importClause.namedBindings;
        const elements = namedBindings && namedBindings.elements && namedBindings.elements;
        if (elements && elements.length === 0) {
            const pos = node.importClause.pos;
            const len = node.importClause.end - node.importClause.pos;
            this.addFailureAt(pos, len, Rule.FAILURE_MESSAGE);
        }
    }
}
